Learn R Programming

sewage (version 0.2.5)

Joiner: Initialize a Joiner object

Description

The Joiner takes in objects and joins them according to a defined method into a single node.

Usage

Joiner(method)

Value

a sewage_joiner object

Arguments

method

function to join incoming objects together

Examples

Run this code
pipeline = Pipeline() |>
    add_node(Joiner(method = rbind), name = "Joiner", input = c("file1", "file2"))

Run the code above in your browser using DataLab