Learn R Programming

sewage (version 0.2.5)

print.sewage_pipeline: Printing Pipelines

Description

print a sewage pipeline

this will print all nodes and theis inputs in the pipeline. Once the pipeline has been executed, print will show the outputs available through [pull_output()]

Usage

# S3 method for sewage_pipeline
print(x, ...)

Value

formatted sewage pipeline output

Arguments

x

a [Pipeline()] object

...

not used

Examples

Run this code
pipeline = Pipeline() |>
    add_node(component = head, name = "Head", input = "file")
print(pipeline)

Run the code above in your browser using DataLab