powered by
The Joiner takes in objects and joins them according to a defined method into a single node.
Joiner
Joiner(method)
a sewage_joiner object
sewage_joiner
function to join incoming objects together
pipeline = Pipeline() |> add_node(Joiner(method = rbind), name = "Joiner", input = c("file1", "file2"))
Run the code above in your browser using DataLab