powered by
print a sewage pipeline
this will print all nodes and theis inputs in the pipeline. Once the pipeline has been executed, print will show the outputs available through [pull_output()]
# S3 method for sewage_pipeline print(x, ...)
formatted sewage pipeline output
a [Pipeline()] object
not used
pipeline = Pipeline() |> add_node(component = head, name = "Head", input = "file") print(pipeline)
Run the code above in your browser using DataLab